@@ -19,7 +19,7 @@ use File::Basename ();
 use File::Path ();
 use File::Spec ();
 use vars qw($VERSION $urllist);
-$VERSION = sprintf "%.6f", substr(q$Rev: 2558 $,4)/1000000 + 5.4;
+$VERSION = sprintf "%.6f", substr(q$Rev: 2652 $,4)/1000000 + 5.4;
 
 =head1 NAME
 
@@ -488,6 +488,18 @@ you will need to configure CPAN::Reporter before sending reports.
 
 Email test reports if CPAN::Reporter is installed (yes/no)?
 
+=item trust_test_report_history
+
+When a distribution has already been tested by CPAN::Reporter on
+this machine, CPAN can skip the test phase and just rely on the
+test report history instead.
+
+Note that this will not apply to distributions that failed tests
+because of missing dependencies.  Also, tests can be run
+regardless of the history using "force".
+
+Do you want to rely on the test report history (yes/no)?
+
 =item use_sqlite
 
 CPAN::SQLite is a layer between the index files that are downloaded
@@ -645,7 +657,7 @@ sub init {
 
         if (!$matcher or 'cpan_home' =~ /$matcher/) {
             my $cpan_home = $CPAN::Config->{cpan_home}
-                || File::Spec->catdir($ENV{HOME}, ".cpan");
+                || File::Spec->catdir(CPAN::HandleConfig::home(), ".cpan");
 
             if (-d $cpan_home) {
                 $CPAN::Frontend->myprint(qq{
@@ -800,6 +812,10 @@ Shall we use it as the general CPAN build and cache directory?
         }
     }
 
+    if (!$matcher or 'trust_test_report_history' =~ /$matcher/) {
+        my_yn_prompt(trust_test_report_history => 0, $matcher);
+    }
+
     #
     #= YAML vs. YAML::Syck
     #
@@ -972,7 +988,8 @@ substitute. You can then revisit this dialog with
     my_dflt_prompt(mbuildpl_arg => "", $matcher);
     my_dflt_prompt(mbuild_arg => "", $matcher);
 
-    if (exists $CPAN::HandleConfig::keys{mbuild_install_build_command}) {
+    if (exists $CPAN::HandleConfig::keys{mbuild_install_build_command}
+	and $^O ne "MSWin32") {
         # as long as Windows needs $self->_build_command, we cannot
         # support sudo on windows :-)
         my_dflt_prompt(mbuild_install_build_command => "./Build", $matcher);
